==> open-cluster-management-operator-model-5.12.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/HubConditionBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HubConditionBuilder extends io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubConditionFluentImpl<io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition,io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubConditionBuilder>{
  public HubConditionBuilder() {
    this(false);
  }
  public HubConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new HubCondition(), validationEnabled);
  }
  public HubConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public HubConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HubCondition(), validationEnabled);
  }
  public HubConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubConditionFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition instance) {
    this(fluent, instance, false);
  }
  public HubConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubConditionFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public HubConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition instance) {
    this(instance,false);
  }
  public HubConditionBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.HubCondition build() {
    HubCondition buildable = new HubCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HubConditionBuilder that = (HubConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-operator-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/HubConditionBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HubConditionBuilder extends HubConditionFluentImpl<HubConditionBuilder> implements VisitableBuilder<HubCondition,HubConditionBuilder>{
  public HubConditionBuilder() {
    this(false);
  }
  public HubConditionBuilder(Boolean validationEnabled) {
    this(new HubCondition(), validationEnabled);
  }
  public HubConditionBuilder(HubConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public HubConditionBuilder(HubConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HubCondition(), validationEnabled);
  }
  public HubConditionBuilder(HubConditionFluent<?> fluent,HubCondition instance) {
    this(fluent, instance, false);
  }
  public HubConditionBuilder(HubConditionFluent<?> fluent,HubCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public HubConditionBuilder(HubCondition instance) {
    this(instance,false);
  }
  public HubConditionBuilder(HubCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  HubConditionFluent<?> fluent;
  Boolean validationEnabled;
  public HubCondition build() {
    HubCondition buildable = new HubCondition(fluent.getLastTransitionTime(),fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    return buildable;
  }
  
}
